summary.mixcure: Summary method for mixture cure models
Description
Summary function will calculate bootstrap variances of the estimates in a
mixcure fit if it detects that the variances do not exist. Then it will print
estimates, their standard errors, z-scores and p-values from normal distribution
Usage
# S3 method for mixcure
summary(object, R = 100, index = 1:2, ...)
Arguments
object
A mixcure object
R
the number of boot samples required to calculate bootstrap
variances.
index
An argument used in censboot function in boot package to
specify the columns in data that store survival times and censoring
indicators
...
other parameters to be passed into print function
Value
A modified mixcure object with extra components:
varboot
a censboot object
stderr
standard errors of parameters in mixcure
R
the number of bootstrap samples used
Details
censboot in boot package is called to calculate bootstrap variances
# NOT RUN {data(leukaemia)
# To reduce running time of this example, R is set to 2.summary(mixcure(Surv(time, cens) ~ transplant, ~ transplant,
data = leukaemia, savedata = TRUE), R = 2)
# }